c converts swift binary (integer,real,real*8) file to an ascii file
c write given PLs and TPs: id, time, a, e, inc, peri, node, m
c Miroslav Broz, miroslav.broz@email.cz, Apr 23rd 2003

      program follow_pltp

c-----------------------------------------------------------------------
      include 'swift.inc'

c input params
      character*80 outfile,infile
      integer ftype

c temp vars
      integer i,id,istep,ierr,nbod,nleft
      real*8 t,tmax,dr,a,e,inc,capom,omega,capm,apo,peri
      character*80 str

      integer maxstr
      parameter(maxstr = NPLMAX+NTPMAX)
      integer j,n,iu
      logical id_print(-NPLMAX:NTPMAX)
      character*5 s(maxstr)
      logical lprint

c functions
      integer io_read_hdr,io_read_line
      integer io_read_hdr_r,io_read_line_r
      integer io_read_hdr_r8,io_read_line_r8
      integer split
      integer iargc

c-----------------------------------------------------------------------

c read input params from stdin
      if (iargc().eq.0) then
        write(0,*) 'follow_pltp: Input binary file:'
        read(*,5) infile
5       format(a)
        write(0,*) 'follow_pltp: Output ASCII file (- for STDOUT):'
        read(*,5) outfile
        write(0,*) 'follow_pltp: Type of binary file (0...integer, ',
     :    '1...real*4, 2...real*8):'
        read(*,*) ftype
        write(0,*) 'follow_pltp: Space separated list of PLs and TPs',
     :    ' to follow (empty for all):'
        read(*,5) str

c check command-line arguments
      else if (iargc().ge.3) then
        call getarg(1, infile)
        call getarg(2, outfile)
        call getarg(3, str)
        read(str,*,err=15,end=15) ftype
        if (iargc().ge.4) then
          call getarg(4, str)
        else
          str = ''
        endif
      else
15      continue
        write(0,*) 'Usage: follow_pltp infile outfile <type [0-2]> ',
     :    '["<space sep. PL and TP list>"]'
        stop
      endif 

c  decode PL/TP list
      n = split(str,' ',s,maxstr)
      if (n.eq.0) then
        do i = -NPLMAX, NTPMAX
          id_print(i) = .true.
        enddo
      else
        do i = -NPLMAX, NTPMAX
          id_print(i) = .false.
        enddo
        do i = 1, n
          read(s(i),*,end=30,err=30) j
          id_print(j) = .true.
        enddo
        goto 35
30      continue
          write(0,*) 'follow_pltp: Incomprehensible PL/TP list.'
          stop
35      continue
      endif

c  check type of binary file
      if (ftype.eq.2) then
c        write(*,*) ' Reading an real*8 binary file '
      else if (ftype.eq.1) then
c        write(*,*) ' Reading an real*4 binary file '
      else if (ftype.eq.0) then
c        write(*,*) ' Reading an integer*2 binary file '
      else
        write(*,*)'# follow_pltp: Unknown binary file format specified.'
        stop
      endif

      tmax = 0
      dr = 180.0/pi

      open(unit=1,file=infile,status='old',form='unformatted',
     :  iostat=ierr)
      if (ierr.ne.0) then
        write(0,*) 'follow_pltp: Error opening file ',infile
        stop
      endif
      if (outfile(1:1).eq.'-') then
        iu=6
      else
        iu=2
c        open(unit=2,file=outfile,status='new',iostat=ierr)
        open(unit=2,file=outfile,status='unknown',iostat=ierr)
        if (ierr.ne.0) then
          write(0,*) 'follow_pltp: Error opening file ',outfile
          stop
        endif
      endif

10    continue
        istep = 0
        if (ftype.eq.2) then
          ierr = io_read_hdr_r8(1,t,nbod,nleft)
        else if (ftype.eq.1) then
          ierr = io_read_hdr_r(1,t,nbod,nleft)
        else if (ftype.eq.0) then
          ierr = io_read_hdr(1,t,nbod,nleft)
        endif
        if (ierr.ne.0) goto 20
        t = t/365.25e6	! Myr
        do i=2,nbod
          if (ftype.eq.2) then
            ierr = io_read_line_r8(1,id,a,e,inc,capom,omega,capm)
          else if (ftype.eq.1) then
            ierr = io_read_line_r(1,id,a,e,inc,capom,omega,capm)
          else
            ierr = io_read_line(1,id,a,e,inc,capom,omega,capm)
          endif
          if (ierr.ne.0) goto 20
          istep = 1
          if (id_print(id)) then
            inc = inc*dr
            capom = capom*dr
            omega = omega*dr
            capm = capm*dr
            write(iu,1000) id,t,a,e,inc,capom,omega,capm
1000        format(1x,i5,1x,f16.10,1x,f14.8,1x,f10.8,4(1x,f10.5))
          endif
        enddo

        do i=1,nleft
          if (ftype.eq.2) then
            ierr = io_read_line_r8(1,id,a,e,inc,capom,omega,capm)
          else if (ftype.eq.1) then
            ierr = io_read_line_r(1,id,a,e,inc,capom,omega,capm)
          else
            ierr = io_read_line(1,id,a,e,inc,capom,omega,capm)
          endif
          if (ierr.ne.0) goto 20
          istep = 1
          if (id_print(id)) then
            inc = inc*dr
            capom = capom*dr
            omega = omega*dr
            capm = capm*dr
            write(iu,1000) id,t,a,e,inc,capom,omega,capm
          endif
          tmax = t
        enddo
        if (istep.eq.0) goto 20
      goto 10
20    continue

      write(0,*) '# follow_pltp: t_max = ',tmax,' Myr'

      stop
      end

